// Sample dataset with x and y values
const dataset = [
  { x: 10, y: 20 },
  { x: 30, y: 40 },
  { x: 50, y: 10 },
  { x: 70, y: 30 },
  { x: 90, y: 50 },
  { x: 83, y: 30 },
  { x: 20, y: 70 },
  { x: 100, y: 50 },
  { x: 22, y: 50 },
  { x: 13, y: 20 },
  { x: 55, y: 13 },
  { x: 78, y: 34 },
  { x: 27, y: 30 },
  { x: 90, y: 50 },
  { x: 85, y: 30 },
  { x: 23, y: 70 },
  { x: 16, y: 50 },
  { x: 40, y: 50 },
  { x: 10, y: 20 },
  { x: 50, y: 19 },
  { x: 12, y: 10 },
  { x: 60, y: 30 },
  { x: 87, y: 50 },
  { x: 99, y: 13 },
  { x: 130, y: 90 },
  { x: 110, y: 13 },
  { x: 120, y: 90 },
  { x: 10, y: 17 },
  { x: 90, y: 13 },
  { x: 07, y: 34 },
  { x: 50, y: 80 },
  { x: 60, y: 55 },
  { x: 70, y: 35 },
  { x: 89, y: 70 },
  { x: 87, y: 60 },
  { x: 14, y: 60 },
  { x: 07, y: 34 },
  { x: 5, y: 80 },
  { x: 60, y: 5 },
  { x: 7, y: 35 },
  { x: 89, y: 70 },
  { x: 83, y: 60 },
  { x: 12, y: 60 },
  // Add more data as needed
];
// Set up chart dimensions
const width = 900;
const height = 400;
const margin = { top: 80, right: 10, bottom: 25, left: 60 };
const chartWidth = width - margin.left - margin.right;
const chartHeight = height - margin.top - margin.bottom;

// Create the SVG element
const svg = d3.select('#chart')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Create the chart group
const chart = svg.append('g')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);

// Create x and y scales
const xScale = d3.scaleLinear()
  .domain([0, d3.max(dataset, d => d.x)])
  .range([0, chartWidth]);

const yScale = d3.scaleLinear()
  .domain([0, d3.max(dataset, d => d.y)])
  .range([chartHeight, 0]);

// Create and append the scatter plot points
chart.selectAll('circle')
  .data(dataset)
  .enter()
  .append('circle')
  .attr('cx', d => xScale(d.x))
  .attr('cy', d => yScale(d.y))
  .attr('r', 5) // Adjust the circle size as needed
  .attr('fill', (d, i) => ['steelblue', 'green', 'orange', 'red'][i]);

// Add x-axis
chart.append('g')
  .attr('transform', `translate(0, ${chartHeight})`)
  .call(d3.axisBottom(xScale));

// Add y-axis
chart.append('g')
  .call(d3.axisLeft(yScale));

// Add x-axis label
svg.append('text')
  .attr('transform', `translate(${width / 3}, ${height - margin.bottom})`)
  .style('text-anchor', 'middle')
  .text('X-axis Label');

// Add y-axis label
svg.append('text')
  .attr('transform', 'rotate(-90)')
  .attr('y', margin.left / 5)
  .attr('x', 0 - height / 2)
  .style('text-anchor', 'middle')
  .text('Y-axis Label');
